#
# spec file for package maven-resolver
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _buildshell /bin/bash
%bcond_with tests
Name:           maven-resolver
Version:        1.9.22
Release:        1.3
Summary:        Apache Maven Artifact Resolver library
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/resolver/
Source0:        https://archive.apache.org/dist/maven/resolver/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.tar.xz
BuildRequires:  ant
BuildRequires:  apache-commons-lang3
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  glassfish-annotation-api
BuildRequires:  google-guice
BuildRequires:  httpcomponents-client
BuildRequires:  httpcomponents-core
BuildRequires:  javapackages-local
BuildRequires:  jcl-over-slf4j
BuildRequires:  maven-wagon-provider-api
BuildRequires:  plexus-classworlds
BuildRequires:  plexus-utils
BuildRequires:  plexus-xml
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  slf4j
BuildRequires:  unzip
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
BuildArch:      noarch
%if %{with tests}
BuildRequires:  ant-junit
BuildRequires:  cglib
BuildRequires:  mockito
BuildRequires:  objectweb-asm
BuildRequires:  objenesis
BuildRequires:  plexus-containers-component-annotations
%endif

%description
Apache Maven Artifact Resolver is a library for working with artifact
repositories and dependency resolution. Maven Artifact Resolver deals with the
specification of local repository, remote repository, developer workspaces,
artifact transports and artifact resolution.

%package api
Summary:        Maven Artifact Resolver API
Group:          Development/Libraries/Java

%description api
The application programming interface for the repository system.

%package spi
Summary:        Maven Artifact Resolver SPI
Group:          Development/Libraries/Java

%description spi
The service provider interface for repository system implementations and
repository connectors.

%package util
Summary:        Maven Artifact Resolver Utilities
Group:          Development/Libraries/Java

%description util
A collection of utility classes to ease usage of the repository system.

%package named-locks
Summary:        Maven Artifact Resolver Named Locks
Group:          Development/Libraries/Java

%description named-locks
A synchronization utility implementation using Named locks

%package impl
Summary:        Maven Artifact Resolver Implementation
Group:          Development/Libraries/Java

%description impl
An implementation of the repository system.

%package test-util
Summary:        Maven Artifact Resolver Test Utilities
Group:          Development/Libraries/Java

%description test-util
A collection of utility classes to ease testing of the repository system.

%package connector-basic
Summary:        Maven Artifact Resolver Connector Basic
Group:          Development/Libraries/Java

%description connector-basic
A repository connector implementation for repositories using URI-based layouts.

%package transport-classpath
Summary:        Maven Artifact Resolver Transport Classpath
Group:          Development/Libraries/Java

%description transport-classpath
A transport implementation for repositories using classpath:// URLs.

%package transport-file
Summary:        Maven Artifact Resolver Transport File
Group:          Development/Libraries/Java

%description transport-file
A transport implementation for repositories using file:// URLs.

%package transport-http
Summary:        Maven Artifact Resolver Transport HTTP
Group:          Development/Libraries/Java

%description transport-http
A transport implementation for repositories using http:// and https:// URLs.

%package transport-wagon
Summary:        Maven Artifact Resolver Transport Wagon
Group:          Development/Libraries/Java

%description transport-wagon
A transport implementation based on Maven Wagon.

%package        javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description    javadoc
This package provides %{summary}.

%prep
%setup -q -a1

# requires internet connection
rm maven-resolver-transport-http/src/test/java/org/eclipse/aether/transport/http/{HttpServer,HttpTransporterTest}.java
%pom_remove_dep org.eclipse.jetty: maven-resolver-transport-http

%pom_remove_plugin -r :bnd-maven-plugin
%pom_remove_plugin -r org.codehaus.mojo:animal-sniffer-maven-plugin
%pom_remove_plugin -r :japicmp-maven-plugin

%pom_disable_module maven-resolver-demos
%pom_disable_module maven-resolver-named-locks-hazelcast
%pom_disable_module maven-resolver-named-locks-redisson
%pom_disable_module maven-resolver-transport-classpath

# generate OSGi manifests
for pom in $(find -mindepth 2 -name pom.xml) ; do
  %pom_add_plugin "org.apache.felix:maven-bundle-plugin" $pom \
  "<configuration>
    <instructions>
      <Bundle-SymbolicName>\${project.groupId}$(sed 's:./maven-resolver::;s:/pom.xml::;s:-:.:g' <<< $pom)</Bundle-SymbolicName>
      <Export-Package>!org.eclipse.aether.internal*,org.eclipse.aether*</Export-Package>
      <_nouses>true</_nouses>
    </instructions>
  </configuration>
  <executions>
    <execution>
      <id>create-manifest</id>
      <phase>process-classes</phase>
      <goals><goal>manifest</goal></goals>
    </execution>
  </executions>"
done
%pom_add_plugin "org.apache.maven.plugins:maven-jar-plugin" pom.xml \
"<configuration>
  <archive>
    <manifestFile>\${project.build.outputDirectory}/META-INF/MANIFEST.MF</manifestFile>
  </archive>
</configuration>"

%{mvn_package} :maven-resolver
%{mvn_package} :maven-resolver-{*}  @1
%{mvn_alias} 'org.apache.maven.resolver:maven-resolver{*}' 'org.eclipse.aether:aether@1'
%{mvn_alias} 'org.apache.maven.resolver:maven-resolver-transport-wagon' 'org.eclipse.aether:aether-connector-wagon'
%{mvn_file} ':maven-resolver{*}' %{name}/maven-resolver@1 aether/aether@1

# Try to avoid sucking in dependencies on packages that are not built at this moment
%pom_remove_parent .
%pom_remove_plugin :maven-jar-plugin .

%build
mkdir -p lib
build-jar-repository -s lib \
  atinject \
  commons-lang3 \
  glassfish-annotation-api \
  guice/google-guice-no_aop \
  httpcomponents/httpclient \
  httpcomponents/httpcore \
  maven-wagon/provider-api \
  org.eclipse.sisu.inject \
  org.eclipse.sisu.plexus \
  plexus-classworlds \
  plexus/utils \
  plexus/xml \
  slf4j/api
%if %{with tests}
build-jar-repository -s lib \
  cglib/cglib \
  mockito/mockito-core \
  objectweb-asm/asm \
  objenesis/objenesis \
  plexus-containers/plexus-component-annotations \
  slf4j/simple
%endif
%{ant} \
%if %{without tests}
  -Dtest.skip=true \
%endif
  package javadoc

%{mvn_artifact} pom.xml

mkdir -p target/site/apidocs
for i in api spi test-util util named-locks impl connector-basic transport-classpath transport-file transport-http transport-wagon; do
  cp -r %{name}-${i}/target/site/apidocs target/site/apidocs/%{name}-${i}
  %{mvn_artifact} %{name}-${i}/pom.xml %{name}-${i}/target/%{name}-${i}-%{version}.jar
done

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files api -f .mfiles-api
%license LICENSE NOTICE

%files spi -f .mfiles-spi

%files util -f .mfiles-util

%files named-locks -f .mfiles-named-locks

%files impl -f .mfiles-impl

%files test-util -f .mfiles-test-util

%files connector-basic -f .mfiles-connector-basic

%files transport-classpath -f .mfiles-transport-classpath

%files transport-file -f .mfiles-transport-file

%files transport-http -f .mfiles-transport-http

%files transport-wagon -f .mfiles-transport-wagon

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Tue Aug 27 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.9.22
  * Bug
    + MRESOLVER-572: Resolver-Supplier unusable in OSGi runtimes
    + MRESOLVER-574: Invalid Cookie set under proxy conditions
    + MRESOLVER-586: In typical setups, DefaultArtifact copies the
    same maps over and over again
    + MRESOLVER-587: Memory consumption improvements
  * New Feature
    + MRESOLVER-571: Import o.e.aether packages with the exact same
    version in OSGi metadata
  * Improvement
    + MRESOLVER-570: Remove excessive strictness of OSGi dependency
    metadata
  * Task
    + MRESOLVER-576: Allow co-release of Resolver 1.x and 2.x
* Wed Jun 12 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.9.20
  * Bug
    + MRESOLVER-483: PreorderNodeListGenerator bug: may print
    trailing ":"
    + MRESOLVER-522: File locking threads not entering critical
    region were "oversleeping"
    + MRESOLVER-547: BF collector always copies artifacts, even
    when it should not
  * Improvement
    + MRESOLVER-536: Skip setting last modified time when FS does
    not support it
* Tue Apr  2 2024 Fridrich Strba <fstrba@suse.com>
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Tue Jan 30 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.9.18
  * Bug
    + MRESOLVER-372: Sporadic AccessDeniedEx on Windows
    + MRESOLVER-441: Undo FileUtils changes that altered non-Windows
    execution path
  * Improvement
    + MRESOLVER-396: Native transport should retry on HTTP 429
    (Retry-After)
  * Task
    + MRESOLVER-397: Deprecate Guice modules
    + MRESOLVER-405: Get rid of component name string literals, make
    them constants and reusable
    + MRESOLVER-433: Expose configuration for inhibiting
    Expect-Continue handshake in 1.x
    + MRESOLVER-435: Refresh download page
    + MRESOLVER-437: Resolver should not override given HTTP
    transport default use of expect-continue handshake
* Thu Sep 21 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.9.15
  * Bug
    + MRESOLVER-373: Remove lock upgrading code
    + MRESOLVER-375: Several key aspects are broken in provided and
    trusted checksum feature
    + MRESOLVER-376: StackOverflowError at
    BfDependencyCollector.processDependency
    + MRESOLVER-380: Lock diagnostic: attempted lock step is
    recorded, but on failed attempt is not removed
    + MRESOLVER-393: Transport HTTP does not retain last modified as
    sent by remote end
  * Improvement
    + MRESOLVER-220: Modify signaling for unsupported operations
    + MRESOLVER-382: Define local outgoing (bind) address
    + MRESOLVER-385: Reduce default value for
    aether.connector.http.connectionMaxTtl
  * Task
    + MRESOLVER-378: Update parent POM to 40
    + MRESOLVER-381: Undo MRESOLVER-373 as it was fixed by other
    means
    + MRESOLVER-386: Make all injected ctors public, deprecate all
    def ctors
    + MRESOLVER-388: Transport HTTP old codec proper override
* Mon Jun 19 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.9.12
  * Bug
    + [MRESOLVER-371] Unjustified WARNING log added by
    MRESOLVER-364
    + [MRESOLVER-361] Unreliable TCP and retries on upload
    + [MRESOLVER-357] ConflictResolver STANDARD verbosity
    misbehaves
    + [MRESOLVER-352] Duplicate METADATA_DOWNLOADING event is
    being sent
  * Improvement
    + [MRESOLVER-360] disable checksum by default for .sigstore
    in addition to .asc
  * New Feature
    + [MRESOLVER-370] Lock factory should dump lock states on
    failure
    + [MRESOLVER-353] Make aether.checksums.algorithms settable
    per remote repository
  * Task
    + [MRESOLVER-366] Upgrade build plugins
    + [MRESOLVER-364] Revert MRESOLVER-132
    + [MRESOLVER-359] Make build be explicit about build time
    requirements
    + [MRESOLVER-356] Remove Guava (is unused)
    + [MRESOLVER-354] Document expected checksums
* Wed May  3 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.9.8
  * Bug
    + [MRESOLVER-345] Conflict resolution in verbose mode is
    sensitive to version ordering
    + [MRESOLVER-348] SslConfig httpSecurityMode change is not
    detected
    + [MRESOLVER-339] Preemptive Auth broken when default ports used
    + [MRESOLVER-325] [REGRESSION] Suddenly seeing I/O errors under
    windows aborting the build
    + [MRESOLVER-330] Static name mapper is unusable with file-lock
    factory
    + [MRESOLVER-314] Getting "IllegalArgumentException: Comparison
    method violates its general contract!"
    + [MRESOLVER-316] DF collector enters endless loop when
    collecting org.webjars.npm:musquette:1.1.1
    + [MRESOLVER-298] javax.inject should be provided or optional
    + [MRESOLVER-305] Evaluate blocked repositories also when
    retrieving metadata
    + [MRESOLVER-309] PrefixesRemoteRepositoryFilterSource aborts
    the build while it should not
    + [MRESOLVER-313] Artifact file permissions are 0600 and not
    implicitly set by umask
    + [MRESOLVER-296] FileProcessor.write( File, InputStream ) is
    defunct
    + [MRESOLVER-292] Documented and used param names mismatch
    + [MRESOLVER-294] Fix JapiCmp configuration and document it
    + [MRESOLVER-285] File locking on Windows knows to misbehave
    + [MRESOLVER-246] m-deploy-p will create hashes for hashes
    + [MRESOLVER-265] Discrepancy between produced and recognized
    checksums
    + [MRESOLVER-241] Resolver checksum calculation should be driven
    by layout
    + [MRESOLVER-242] When no remote checksums provided by layout,
    transfer inevitably fails/warns
    + [MRESOLVER-250] Usage of descriptors map in DataPool prevents
    gargabe collection
  * New Feature
    + [MRESOLVER-32] Support parallel artifact/metadata uploads
    + [MRESOLVER-319] Support parallel deploy
    + [MRESOLVER-297] Chained LRM
    + [MRESOLVER-167] Support forcing specific repositories for
    artifacts
    + [MRESOLVER-268] Apply artifact checksum verification for any
    resolved artifact
    + [MRESOLVER-274] Introduce Remote Repository Filter feature
    + [MRESOLVER-275] Introduce trusted checksums source
    + [MRESOLVER-276] Resolver post-processor
    + [MRESOLVER-278] BREAKING: Introduce RepositorySystem shutdown
    hooks
    + [MRESOLVER-236] Make it possible to resolve .asc on a 'fail'
    respository.
  * Improvement
    + [MRESOLVER-346] Too eager locking
    + [MRESOLVER-347] Better connection pool configuration (reuse,
    max TTL, maxPerRoute)
    + [MRESOLVER-349] Adapter when locking should "give up and
    retry"
    + [MRESOLVER-350] Get rid of commons-lang dependency
    + [MRESOLVER-327] Make tranport-http obey system properties
    regarding proxy settings
    + [MRESOLVER-340] Make WebDAV "dance" disabled by default
    + [MRESOLVER-341] Add option for preemptive PUT Auth
    + [MRESOLVER-315] Implement preemptive authentication feature
    for transport-http
    + [MRESOLVER-328] The transport-http should be able to ignore
    cert errors
    + [MRESOLVER-337] Real cause when artifact not found with
    repository filtering
    + [MRESOLVER-287] Get rid of deprecated finalize methods
    + [MRESOLVER-317] Improvements for BF collector
    + [MRESOLVER-318] Cleanup redundant code and centralize executor
    handling
    + [MRESOLVER-303] Make checksum detection reusable
    + [MRESOLVER-290] Improve file handling resolver wide
    + [MRESOLVER-7] Download dependency POMs in parallel in BF
    collector
    + [MRESOLVER-266] Simplify adapter creation and align
    configuration for it
    + [MRESOLVER-269] Allow more compact storage of provided
    checksums
    + [MRESOLVER-273] Create more compact File locking layout/mapper
    + [MRESOLVER-284] BREAKING: Some Sisu parameters needs to be
    bound
    + [MRESOLVER-286] Improve basic connector closed state handling
    + [MRESOLVER-240] Using breadth-first approach to resolve Maven
    dependencies
    + [MRESOLVER-247] Avoid unnecessary dependency resolution by a
    Skip solution based on BFS
    + [MRESOLVER-248] Make DF and BF collector implementations
    coexist
  * Task
    + [MRESOLVER-326] Resolver transport-http should retry on
    failures
    + [MRESOLVER-331] Make DefaultTrackingFileManager write directly
    to tracking files
    + [MRESOLVER-333] Distinguish better resolver errors for
    artifact availability
    + [MRESOLVER-320] Investigate slower resolving speeds as
    reported by users
    + [MRESOLVER-291] Undo MRESOLVER-284
    + [MRESOLVER-279] Simplify and improve trusted checksum sources
    + [MRESOLVER-281] Update configurations page with new elements
    + [MRESOLVER-282] Drop PartialFile
    + [MRESOLVER-230] Make supported checksum algorithms extensible
    + [MRESOLVER-231] Extend “smart checksum” feature
    + [MRESOLVER-234] Introduce “provided” checksums feature
    + [MRESOLVER-237] Make all checksum mismatches handled same
    + [MRESOLVER-239] Update and sanitize dependencies
    + [MRESOLVER-244] Deprecate FileTransformer API
    + [MRESOLVER-245] Isolate Hazelcast tests
  * Dependency upgrade
    + [MRESOLVER-311] Upgrade Parent to 39
    + [MRESOLVER-293] Update dependencies, align with Maven
    + [MRESOLVER-272] Update parent POM to 37, remove plugin version
    overrides, update bnd
    + [MRESOLVER-280] Upgrade invoker, install, deploy, require
    maven 3.8.4+
    + [MRESOLVER-251] Upgrade Redisson to 3.17.5
    + [MRESOLVER-249] Update Hazelcast to 5.1.1 in
    named-locks-hazelcast module
* Sat May 21 2022 Fridrich Strba <fstrba@suse.com>
- Add an alias for the wagon connector
* Wed Mar 30 2022 Fridrich Strba <fstrba@suse.com>
- Build against the standalone JavaEE modules unconditionally
* Sat Mar 19 2022 Fridrich Strba <fstrba@suse.com>
- Remove the javax.annotation:javax.annotation-api dependency on
  distribution versions that do not incorporate the JavaEE modules
* Thu Mar 17 2022 Fridrich Strba <fstrba@suse.com>
- Add the glassfish-annotation-api jar to the build classpath
* Fri Mar 11 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.7.3
  * Bug
    + [MRESOLVER-96] - Dependency Injection fails after upgrading
    to Maven 3.6.2
    + [MRESOLVER-153] - resolver-status.properties file is corrupted
    due to concurrent writes
    + [MRESOLVER-171] - Resolver fails when compiled on Java 9+ an
    run on Java 8 due to JDK API breakage
    + [MRESOLVER-189] - Using semaphore-redisson followed by
    rwlock-redisson on many parallel build of the same project
    triggers redisson error
  * New Feature
    + [MRESOLVER-90] - HTML content in POM: Maven should validate
    content before storing in local repo
    + [MRESOLVER-145] - Introduce more SyncContext implementations
  * Improvement
    + [MRESOLVER-103] - Replace deprecated HttpClient classes
    + [MRESOLVER-104] - maven-resolver-demo-maven-plugin uses
    reserved artifactId
    + [MRESOLVER-147] - Upgrade to Java 8
    + [MRESOLVER-148] - Use vanilla Guice 4 instead of forked
    Guice 3
    + [MRESOLVER-156] - Active dependency management for Google
    Guice/Guava
    + [MRESOLVER-168] - add DEBUG message when downloading an
    artifact from repositories
    + [MRESOLVER-193] - Properly type lock key names in Redis
    + [MRESOLVER-197] - Minors improvements (umbrella)
    + [MRESOLVER-204] - Add a SessionData#computeIfAbsent method
    + [MRESOLVER-214] - Remove clirr configuration
  * Task
    + [MRESOLVER-141] - Review index-based access to collections
    + [MRESOLVER-151] - Enforce a checksum policy to be provided
    explicitly
    + [MRESOLVER-152] - Perform null checks when interface
    contracts require it
    + [MRESOLVER-154] - Move SyncContextFactory interface to SPI
    module
    + [MRESOLVER-155] - Make TrackingFileManager member of
    DefaultUpdateCheckManager
    + [MRESOLVER-158] - Simplify SimpleDigest class
    + [MRESOLVER-159] - Mark singleton components as Sisu Singletons
    + [MRESOLVER-160] - Deprecate ServiceLocator
    + [MRESOLVER-162] - Restore binary compatibility broken by
    MRESOLVER-154
    + [MRESOLVER-170] - Deprecate org.eclipse.aether.spi.log
    + [MRESOLVER-172] - Make TrackingFileManager shared singleton
    component
    + [MRESOLVER-173] - Drop deprecated AetherModule
    + [MRESOLVER-174] - Use all bindings in UTs and tests
    + [MRESOLVER-175] - Drop SyncContextFactory delegates in favor
    of a selector approach
    + [MRESOLVER-177] - Move pre-/post-processing of metadata from
    ResolveTask to DefaultMetadataResolver
    + [MRESOLVER-183] - Don't require optional dependencies for
    Redisson
    + [MRESOLVER-184] - Destroy Redisson semaphores if not used
    anymore
    + [MRESOLVER-186] - Update Maven version in Resolver Demo
    Snippets
    + [MRESOLVER-188] - Improve documentation on using the named
    locks with redis/hazelcast (umbrella)
    + [MRESOLVER-190] - [Regression] Revert MRESOLVER-184
    + [MRESOLVER-191] - Document how to analyze lock issues
    + [MRESOLVER-196] - Document named locks configuration options
    + [MRESOLVER-219] - Implement NamedLock with advisory file
    locking
    + [MRESOLVER-227] - Refactor NamedLockFactorySelector to a
    managed component
    + [MRESOLVER-232] - Make SimpleNamedLockFactorySelector logic
    reusable
  * Sub-task
    + [MRESOLVER-198] - Replace assert by simpler but equivalent
    calls
    + [MRESOLVER-199] - Java 8 improvements
    + [MRESOLVER-200] - Simplify conditions with the same result
    and avoid extra validations
    + [MRESOLVER-201] - Make variables final whenever possible
    + [MRESOLVER-202] - Use isEmpty() instead length() <= 0
  * Dependency upgrade
    + [MRESOLVER-185] - Upgrade Redisson to 3.15.6
  * Change of API and incompatible with maven-resolver < 1.7
* Thu Jan 13 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.6.3
  * Bug
    + [MRESOLVER-153] - resolver-status.properties file is corrupted
    due to concurrent writes
    + [MRESOLVER-171] - Resolver fails when compiled on Java 9+ and
    run on Java 8 due to JDK API breakage
  * Improvement
    + [MRESOLVER-168] - add DEBUG message when downloading an
    artifact from repositories
  * Task
    + [MRESOLVER-177] - Move pre-/post-processing of metadata from
    ResolveTask to DefaultMetadataResolver
  * Needed for maven 3.8.4
- Removed patch:
  * maven-resolver-1.3.1-java8compat.patch
    + fixed upstream
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not build/run the tests against the legacy guava20 package
* Mon Apr 26 2021 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.6.2
  * Sub-task
    + [MRESOLVER-139] - Make SimpleDigest use SHA-1 or MD5 only
    + [MRESOLVER-140] - Default to SHA-1 and MD5 hashing algorithms
  * Bug
    + [MRESOLVER-25] - Resume support is broken under high
    concurrency
    + [MRESOLVER-114] - ArtifactNotFoundExceptions when building in
    parallel
    + [MRESOLVER-129] - Exclusion has no setters
    + [MRESOLVER-137] - Make OSGi bundles reproducible
    + [MRESOLVER-138] - MRESOLVER-56 introduces severe performance
    regression
  * New Feature
    + [MRESOLVER-109] - AndDependencySelector should override
    toString
    + [MRESOLVER-115] - Make checksum algorithms configurable
    + [MRESOLVER-123] - Provide a global locking sync context by
    default
    + [MRESOLVER-131] - Introduce a Redisson-based
    SyncContextFactory
    + [MRESOLVER-165] - Add support for mirror selector on
    external:http:*
    + [MRESOLVER-166] - Add support for blocked
    repositories/mirrors
  * Improvement
    + [MRESOLVER-56] - Support SHA-256 and SHA-512 as checksums
    + [MRESOLVER-116] - Add page with all supported configuration
    options
    + [MRESOLVER-125] - Use type conversions returning primitives
    + [MRESOLVER-127] - Don't use boolean for property
    'aether.updateCheckManager.sessionState'
    + [MRESOLVER-136] - Migrate from maven-bundle-plugin to
    bnd-maven-plugin
  * Task
    + [MRESOLVER-119] - Turn log messages to SLF4J placeholders
    + [MRESOLVER-130] - Move GlobalSyncContextFactory to a separate
    module
    + [MRESOLVER-132] - Remove synchronization in
    TrackingFileManager
  * Dependency upgrade
    + [MRESOLVER-105] - Update Plexus Components
    + [MRESOLVER-106] - Update HttpComponents
    + [MRESOLVER-107] - Update Wagon Provider API to 3.4.0
    + [MRESOLVER-108] - Update mockito-core to 2.28.2
    + [MRESOLVER-117] - Upgrade SLF4J to 1.7.30
    + [MRESOLVER-118] - Upgrade Sisu Components to 0.3.4
  * Needed for maven 3.8.x
* Tue Feb  2 2021 Jan Engelhardt <jengelh@inai.de>
- Set buildshell to bash for "<<<".
* Tue Dec 29 2020 Wang Jun <jgwang@suse.com>
- Upgrade to upstream version 1.4.2
  * Bug:
    + MRESOLVER-38 – SOE/OOME in DefaultDependencyNode.accept
  * Improvements:
    + MRESOLVER-93 – PathRecordingDependencyVisitor to handle 3 cycles
    + MRESOLVER-102 – make build Reproducible
* Mon Dec  9 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.4.1
  * Task
    + [MRESOLVER-92] - Revert MRESOLVER-7
  * Bug
    + [MRESOLVER-86] - ResolveArtifactMojo from resolver example
    uses plugin repositories to resolve dependencies
  * New Feature
    + [MRESOLVER-10] - New 'TransitiveDependencyManager'
    supporting transitive dependency management
    + [MRESOLVER-33] - New 'DefaultDependencyManager' managing
    dependencies on all levels supporting transitive dependency
    management
  * Improvement
    + [MRESOLVER-7] - Download dependency POMs in parallel
    + [MRESOLVER-84] - Add support for "release" qualifier
    + [MRESOLVER-87] - Refresh examples to use maven-resolver
    artifacts for demo
    + [MRESOLVER-88] - Code style cleanup to use Java 7 features
* Wed Mar 20 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-resolver 1.3.1
- Generate and customize the ant build files
- Added patch:
  * maven-resolver-1.3.1-java8compat.patch
    + avoid calling APIs added in Java 9
